TELEWORK TELEWORK TELEWORK

特集

テレワークのさらなる普及·定着に向け「テレワーク月間」を実施します! TELEWORK

ORK TELEWORK TELEWORK TELEWORK TELEWORK TELEWORK

# テレワークのさらなる普及·定着に向け
「テレワーク月間」
を実施します!

今年度は育児·介護休業法の改正法が成立し、
来年度以降は3歳未満の子を育てる社員がテレ
ワークを選択できるように措置を講ずることが、
事業主の努力義務になります。

総務省では、地方や中小企業等を含め、テレ
ワークの活用により、多様な働き手が活躍の機
会を持てるよう、テレビ番組とのタイアップを
通じて、テレワークの必要性を改めて実感でき
るような情報発信を行います。また、全国の総
合通信局等では、それぞれの地域における取組
やテレワーク活用を進める先進企業を紹介する
催しを実施します。

総務省は、内閣官房、内閣府、デジタル庁、
厚生労働省、経済産業省、国土交通省、観光庁、
環境省、日本テレワーク協会、日本テレワーク
学会と連携して、11月をテレワーク月間とし、
テレワークのさらなる普及·定着に向けた各種
イベント等を集中的に開催します。テレワーク
月間期間中は駅構内やイベント会場等にポス
ターを掲出するほか、ホームページ(※)にて、テ
レワーク実施団体·実施者の登録受付や、テレ
ワーク活用に関するトピック·コンテンツの掲
載、各種イベントに係る情報発信等を行います。

令和6年度テレワーク月間ポスター

※テレワーク月間ホームページ

https://teleworkgekkan.go.jp/

特集

テレワーク月間最終週の11月25日(月)には、内閣府、総務省、厚生労働省、
経済産業省、国土交通省主催で「働く、を変える」テレワークイベントを開催し、
テレワークトップランナー 2024(総務大臣賞)、輝くテレワーク大賞(厚生労
働大臣)および地方創生テレワークアワード(地方創生担当大臣賞)の合同表彰
式を実施予定です。

総務省では、平成27年度から、テレワークの導入·活用を進めている企業·
団体を「テレワーク先駆者」とし、その中から十分な実績を持つ企業·団体等を
「テレワーク先駆者百選」として公表するとともに、平成28年度には「テレワー
ク先駆者百選 総務大臣賞」を創設し、「テレワーク先駆者百選」の中から特に優
れた取組を表彰してきました。

新型コロナウイルス感染症の拡大に際して、企業·団体等においてテレワー
クの導入が進んだ経緯を踏まえ、令和5年度からは、名称や一部の審査基準を
見直したうえで、新たに「テレワークトップランナー」として先進企業の公表、
表彰を開始しました。本年は、テレワークの活用による経営効果の発揮やテレ
ワーク導入が馴染まないと思われている業態の企業におけるテレワーク活用·
業務改革等について、特色ある優れた取組等を実施している企業·団体を「テ
レワークトップランナー 2024」として選定·公表し、その中から特に優れた取
組を「テレワークトップランナー 2024総務大臣賞」として表彰します。※今年度の
表彰団体の募集は、すでに終了しています。

表彰式は、会場(御茶ノ水ソラシティ、東京都)での観覧の他、オンライン配
信も実施予定です。

テレワークの必要性について考え直すきっかけとなるよう、各種イベントに
ご参加いただくとともに、テレワーク月間実施団体·実施者としての登録の呼
びかけについても、是非、ご協力をお願いします。

テレワークトップランナー 2023 総務大臣賞受賞企業

企業名 (五十音順) | 業種、所在地、 従業員数 | 取組の特徴
|アフラック生命 保険株式会社 | 金融 ·保険業 東京都、4910人 | ·20-30 代の女性の離職率が半減、育児に関わる短時間勤務制度を利用 する社員の人数が 27.9%減少(フルタイムの増加)など、女性の仕事 と家庭の両立、キャリア形成に寄与 ·通勤手当 39.3%削減、紙帳票のペーパレス化等により、コストダウンの 効果も顕在化
株式会社 キャリア・マム | サービス業 東京都、38人 | ·11万人の主婦会員のうち、年間約3,000 人の地方在住テレワーカーに 業務発注を行い、就労支援を実施するとともに、在宅ワーカーとしての 人材育成を実施、 ·地方自治体と連携し、地域でのテレワーカーの創出、テレワーク活用の 裾野拡大に貢献
シェイプウィン 株式会社 | 専門 · 技術サービス業 東京都、17人 | ·フルリモートでの勤務も可能とし、求人応募数が約7倍に増加。東京 では人材獲得の競争が激しい PR·マーケティング系の専門人材を地方 や海外から採用 ·離職率は約 80%から約 14%まで低下
株式会社 スタッフサービス· クラウドワーク | サービス業 神奈川県、454人 | ·通勤が困難な 454 名の重度身体障がい者の雇用を創出。入社1年後の 定着率は97.3%。 ·入社後、配属前2ヶ月間のコミュニケーション研修を実施する他、自 主性を重んじた1日3回の定時ミーティングにより、社員による主体的 なチーム運営を実現!
株式会社 テレワーク マネジメント | 専門 · 技術サービス業 北海道、11人 | ・社内SNS及びバーチャルオフィスにて社内コミュニケーションを統一し、 全員が同じルールの下で活用することを徹底することで、効率の良い意 思疎通、社員の一体感の醸成を図っている ·簡単な操作で細かく労働時間を記録できるシステムの運用により、フェ アに働ける環境を実現
株式会社 プログレス | 情報通信業 東京都、86人 | ·コミュニケーションの促進に向け、対面でのチームビルディング、バーチャ ルオフィスの活用等、多数の取り組みを進める他、コミュニケーション 時の留意点等を示したガイドを全社員に向けて公開 ·リーダー間でのメンバー状態の共有、社員への毎月サーベイを実施し、 社員の変化に対し、きめ細やか且つ早期にフォローできる仕組みを構築

主催者代表挨拶
(小森総務大臣政務官)

表彰状授与

受賞企業集合写真(3府省合同)

テレワークトップランナー 2023
ロゴマーク

テレワーク月間関連イベントの様子

※総務省主催セミナー「ニューノー
マル時代に求められる働き方·
環境整備の実態」

セミナーのアーカイブ動画を、
テレワーク月間ホームページに
て公開しております。

https://teleworkgekkan.go.jp/events/
telework-seminar-202403.html

3

2

MIC 2024 November Vol.287

2024 November Vol.287 MIC .